@@ -1,16 +1,18 @@
-use crate::{external::Vcs, mit::cmd::errors::Error};
+use miette::{Result, WrapErr};
+
+use crate::external::Vcs;
 
 #[allow(clippy::maybe_infinite_iter)]
 pub(crate) fn get_vcs_coauthors_config<'a>(
     config: &'a dyn Vcs,
     key: &'a str,
-) -> Result<Vec<Option<&'a str>>, Error> {
+) -> Result<Vec<Option<&'a str>>> {
     (0..)
         .take_while(|index| has_vcs_coauthor(config, *index))
         .map(|index| get_vcs_coauthor_config(config, key, index))
         .fold(Ok(Vec::<Option<&'a str>>::new()), |acc, item| {
             match (acc, item) {
-                (Err(error), _) | (Ok(_), Err(error)) => Err(error),
+                (Err(error), _) | (Ok(_), Err(error)) => Err(error).wrap_err("failed to read "),
                 (Ok(list), Ok(item)) => Ok(vec![list, vec![item]].concat()),
             }
         })
@@ -27,8 +29,6 @@ pub(crate) fn get_vcs_coauthor_config<'a>(
     config: &'a dyn Vcs,
     key: &str,
     index: i32,
-) -> Result<Option<&'a str>, Error> {
-    config
-        .get_str(&format!("mit.author.coauthors.{}.{}", index, key))
-        .map_err(Error::from)
+) -> Result<Option<&'a str>> {
+    config.get_str(&format!("mit.author.coauthors.{}.{}", index, key))
 }
